==> h-vue3-components-dev-1.0.11.tgz: package/es/src/packages/components/forms/dialog/Dialog.vue.js <==
import { inject as h, computed as O, ref as p, resolveComponent as j, openBlock as A, createElementBlock as B, Fragment as C, createVNode as v, unref as o, isRef as b } from "vue";
import g from "../../../utils/formUtil.js";
import P from "../../dialog/tableDialog/TableDialog.vue.js";
import { getPlaceholder as R } from "../../../utils/i18nUtil.js";
import "../../../store/index.js";
import { useRoute as q } from "vue-router";
const J = {
  __name: "Dialog",
  props: {
    option: {
      type: Object,
      default() {
        return {};
      }
    },
    event: Object,
    modelValue: String | Number
  },
  emits: ["update:modelValue"],
  setup(w, { emit: N }) {
    const y = h("formData"), c = h("changeFieldData"), Q = q(), i = w, S = N, s = O({
      get: () => i.modelValue,
      set: (e) => {
        S("update:modelValue", e);
      }
    }), m = O({
      get: () => y.value[i.option.fieldDesc],
      set: (e) => {
        y.value[i.option.fieldDesc] = e;
      }
    }), D = p({}), k = p({}), x = p(""), T = p(""), d = p("checkbox"), F = p(""), f = p(!1);
    function _() {
      let e = i.option.option, t = s.value;
      e.isInDialog = !0, e.isAutoHeight = !0, e.type == "checkbox" ? (t = t.split(","), d.value = "checkbox") : d.value = "radio", F.value = t;
      let n = e.params;
      if (n) {
        let l = n.split(";");
        for (let a in l) {
          let u = l[a].split("-"), r = u[0], V = u[1];
          V = g.parsFieldName(V, y.value, Q), k.value[r] = V;
        }
      }
      if (e.modelType = "dynamicModel", e.isDynamicQuery = e.search, e.isDynamicQuery) {
        let l = [];
        for (let a in e.columns)
          l.push(e.columns[a].prop);
        e.dynamicQuery = {
          prop: "dynamicQueryProp",
          fieldNames: l,
          fieldType: "dynamicQuery"
        };
      }
      D.value = e, x.value = e.title, T.value = e.entitle, f.value = !0;
    }
    const E = h("parentVm");
    function U(e) {
      let t = i.option.option;
      if (d.value == "checkbox") {
        let a = "", u = "";
        for (let r = 0; r < e.length; r++)
          a += e[r][t.pkey], u += e[r][t.showField], r < e.length - 1 && (a += ",", u += ",");
        m.value = u, s.value = a + "@@@" + u, c && c(i.option.fieldName, a);
      } else
        m.value = e[t.showField], s.value = e[t.pkey] + "@@@" + e[t.showField], c && c(i.option.fieldName, e[t.pkey]);
      const n = t.saveCallBack, l = g.parentVmExist(E, n);
      l && l[n](e);
    }
    return (e, t) => {
      const n = j("el-input");
      return A(), B(C, null, [
        v(n, {
          ref: "input",
          type: "text",
          modelValue: o(m),
          "onUpdate:modelValue": t[0] || (t[0] = (l) => b(m) ? m.value = l : null),
          onClick: _,
          placeholder: o(R)(i.option),
          disabled: o(g).isEmpty(i.option.disabled) ? !1 : i.option.disabled,
          readonly: !0
        }, null, 8, ["modelValue", "placeholder", "disabled"]),
        v(n, {
          type: "hidden",
          modelValue: o(s),
          "onUpdate:modelValue": t[1] || (t[1] = (l) => b(s) ? s.value = l : null),
          readonly: !0
        }, null, 8, ["modelValue"]),
        v(o(P), {
          modelValue: o(f),
          "onUpdate:modelValue": t[2] || (t[2] = (l) => b(f) ? f.value = l : null),
          initOption: o(D),
          initSearchData: o(k),
          title: o(x),
          entitle: o(T),
          selectType: o(d),
          selectValue: o(F),
          onSubmit: U
        }, null, 8, ["modelValue", "initOption", "initSearchData", "title", "entitle", "selectType", "selectValue"])
      ], 64);
    };
  }
};
export {
  J as default
};

==> h-vue3-components-dev-1.0.31.tgz: package/es/src/packages/components/forms/dialog/Dialog.vue.js <==
import "../../../../../node_modules/element-plus/theme-chalk/base.css.js";
import "../../../../../node_modules/element-plus/theme-chalk/el-input.css.js";
import { inject as h, computed as O, ref as p, openBlock as j, createElementBlock as A, Fragment as B, createVNode as v, unref as o, isRef as b } from "vue";
import g from "../../../utils/formUtil.js";
import P from "../../dialog/tableDialog/TableDialog.vue.js";
import { getPlaceholder as C } from "../../../utils/i18nUtil.js";
import "../../../store/index.js";
import { useRoute as I } from "vue-router";
import { ElInput as R } from "../../../../../node_modules/element-plus/es/components/input/index.js";
const W = {
  __name: "Dialog",
  props: {
    option: {
      type: Object,
      default() {
        return {};
      }
    },
    event: Object,
    modelValue: String | Number
  },
  emits: ["update:modelValue"],
  setup(w, { emit: N }) {
    const y = h("formData"), c = h("changeFieldData"), E = I(), i = w, Q = N, s = O({
      get: () => i.modelValue,
      set: (e) => {
        Q("update:modelValue", e);
      }
    }), m = O({
      get: () => y.value[i.option.fieldDesc],
      set: (e) => {
        y.value[i.option.fieldDesc] = e;
      }
    }), D = p({}), k = p({}), x = p(""), T = p(""), d = p("checkbox"), F = p(""), f = p(!1);
    function S() {
      let e = i.option.option, t = s.value;
      e.isInDialog = !0, e.isAutoHeight = !0, e.type == "checkbox" ? (t = t.split(","), d.value = "checkbox") : d.value = "radio", F.value = t;
      let a = e.params;
      if (a) {
        let l = a.split(";");
        for (let n in l) {
          let r = l[n].split("-"), u = r[0], V = r[1];
          V = g.parsFieldName(V, y.value, E), k.value[u] = V;
        }
      }
      if (e.modelType = "dynamicModel", e.isDynamicQuery = e.search, e.isDynamicQuery) {
        let l = [];
        for (let n in e.columns)
          l.push(e.columns[n].prop);
        e.dynamicQuery = {
          prop: "dynamicQueryProp",
          fieldNames: l,
          fieldType: "dynamicQuery"
        };
      }
      D.value = e, x.value = e.title, T.value = e.entitle, f.value = !0;
    }
    const _ = h("parentVm");
    function U(e) {
      let t = i.option.option;
      if (d.value == "checkbox") {
        let n = "", r = "";
        for (let u = 0; u < e.length; u++)
          n += e[u][t.pkey], r += e[u][t.showField], u < e.length - 1 && (n += ",", r += ",");
        m.value = r, s.value = n + "@@@" + r, c && c(i.option.fieldName, n);
      } else
        m.value = e[t.showField], s.value = e[t.pkey] + "@@@" + e[t.showField], c && c(i.option.fieldName, e[t.pkey]);
      const a = t.saveCallBack, l = g.parentVmExist(_, a);
      l && l[a](e);
    }
    return (e, t) => {
      const a = R;
      return j(), A(B, null, [
        v(a, {
          ref: "input",
          type: "text",
          modelValue: o(m),
          "onUpdate:modelValue": t[0] || (t[0] = (l) => b(m) ? m.value = l : null),
          onClick: S,
          placeholder: o(C)(i.option),
          disabled: o(g).isEmpty(i.option.disabled) ? !1 : i.option.disabled,
          readonly: !0
        }, null, 8, ["modelValue", "placeholder", "disabled"]),
        v(a, {
          type: "hidden",
          modelValue: o(s),
          "onUpdate:modelValue": t[1] || (t[1] = (l) => b(s) ? s.value = l : null),
          readonly: !0
        }, null, 8, ["modelValue"]),
        v(o(P), {
          modelValue: o(f),
          "onUpdate:modelValue": t[2] || (t[2] = (l) => b(f) ? f.value = l : null),
          initOption: o(D),
          initSearchData: o(k),
          title: o(x),
          entitle: o(T),
          selectType: o(d),
          selectValue: o(F),
          onSubmit: U
        }, null, 8, ["modelValue", "initOption", "initSearchData", "title", "entitle", "selectType", "selectValue"])
      ], 64);
    };
  }
};
export {
  W as default
};
